# 1D particle tracking

Particle tracking in kymographs. 

## Installation

`pip install particle-tracker-one-d`

## Documentation
Documentation can be found at [readthedocs](https://1d-particle-tracking.readthedocs.io/en/latest/index.html)

